@@ -1,4 +1,4 @@
-VERSION='1.12.1'
+VERSION='1.13.0'
 
 from cx_Freeze import setup, Executable
 import os
@@ -69,6 +69,8 @@ def addicons():
         'actions/open-menu',
         'actions/zoom-in',
         'actions/zoom-out',
+        'actions/go-up',
+        'actions/go-down',
         'ui/pan-down',
         'ui/pan-end',
         'ui/pan-start',
@@ -127,6 +129,15 @@ addfile("share/glib-2.0/schemas/gschemas.compiled")
 addicons()
 
 
+# Add encoding files required to correctly display Chinese, Japanese, Korean
+# and some Cyrillic characters in PDF documents. (from poppler-data package)
+from_path = os.path.join(sys.prefix, 'share/poppler/')
+to_path = 'lib/share/poppler/'
+include_files.append((from_path, to_path))
+addfile('share/licenses/poppler-data/COPYING')
+addfile('share/licenses/poppler-data/COPYING.adobe')
+
+
 # gspawn-helper is needed for website link in AboutDialog
 from_path = os.path.join(sys.prefix, 'bin', 'gspawn-win64-helper.exe')
 to_path = 'gspawn-win64-helper.exe'
@@ -145,6 +156,7 @@ def get_target_name(suffix):
 
 
 msi_options = dict(
+    target_name=get_target_name('installer.msi'),
     upgrade_code='{ab1752a6-575c-42e1-a261-b85cb8a6b524}',
     extensions=[{
         "extension": "pdf",
@@ -196,16 +208,3 @@ setup(name='PDF Arranger',
                               shortcut_name='PDF Arranger',
                               shortcut_dir='StartMenuFolder'
                               )])
-
-
-def rename_msi():
-    # cx_freeze 6.15: Workaround for having different filename and "ProductName" for the msi.
-    dist_dir = os.path.join(os.getcwd(), 'dist')
-    msi = [f for f in os.listdir(dist_dir) if f.endswith('.msi')]
-    if len(msi) > 0:
-        old_name = os.path.join(dist_dir, msi[0])
-        new_name = os.path.join(dist_dir, get_target_name('installer.msi'))
-        shutil.move(old_name, new_name)
-
-if 'bdist_msi' in sys.argv:
-    rename_msi()
